@@ -28,6 +28,7 @@ type restoreStatus struct {
 	StartPointInTime int64           `json:"start-point-in-time,omitempty"`
 	PointInTime      int64           `json:"point-in-time,omitempty"`
 	Name             string          `json:"name,omitempty"`
+	Namespaces       []string        `json:"namespaces,omitempty"`
 	Error            string          `json:"error,omitempty"`
 }
 
@@ -41,7 +42,6 @@ const (
 
 type restoreListOut struct {
 	list []restoreStatus
-	full bool
 }
 
 func (r restoreListOut) String() string {
@@ -50,21 +50,27 @@ func (r restoreListOut) String() string {
 		var rprint, name string
 
 		if v.Type == restoreSnapshot {
-			name = v.Snapshot
+			n := ""
+			if len(v.Namespaces) != 0 {
+				n = ", selective"
+			}
+			name = fmt.Sprintf("%s [backup: %s%s]", v.Name, v.Snapshot, n)
 		} else if v.Type == restoreReplay {
 			name = fmt.Sprintf("Oplog Replay: %v - %v",
 				time.Unix(v.StartPointInTime, 0).UTC().Format(time.RFC3339),
 				time.Unix(v.PointInTime, 0).UTC().Format(time.RFC3339))
 		} else {
-			name = "PITR: " + time.Unix(v.PointInTime, 0).UTC().Format(time.RFC3339)
-		}
-		if r.full {
-			name += fmt.Sprintf(" [%s]", v.Name)
+			n := ""
+			if len(v.Namespaces) != 0 {
+				n = ", selective"
+			}
+			name = fmt.Sprintf("PITR: %s [restore time: %s%s]",
+				v.Name, time.Unix(v.PointInTime, 0).UTC().Format(time.RFC3339), n)
 		}
 
 		switch v.Status {
-		case pbm.StatusDone:
-			rprint = name
+		case pbm.StatusDone, pbm.StatusPartlyDone:
+			rprint = fmt.Sprintf("%s\t%s", name, v.Status)
 		case pbm.StatusError:
 			rprint = fmt.Sprintf("%s\tFailed with \"%s\"", name, v.Error)
 		default:
@@ -86,7 +92,7 @@ func runList(cn *pbm.PBM, l *listOpts) (fmt.Stringer, error) {
 	}
 
 	if l.restore {
-		return restoreList(cn, int64(l.size), l.full)
+		return restoreList(cn, int64(l.size))
 	}
 	// show message and skip when resync is running
 	lk, err := findLock(cn, cn.GetLocks)
@@ -97,13 +103,13 @@ func runList(cn *pbm.PBM, l *listOpts) (fmt.Stringer, error) {
 	return backupList(cn, l.size, l.full, l.unbacked, rsMap)
 }
 
-func restoreList(cn *pbm.PBM, size int64, full bool) (*restoreListOut, error) {
+func restoreList(cn *pbm.PBM, size int64) (*restoreListOut, error) {
 	rlist, err := cn.RestoresList(size)
 	if err != nil {
 		return nil, errors.Wrap(err, "unable to get restore list")
 	}
 
-	rout := &restoreListOut{full: full}
+	rout := &restoreListOut{}
 	for i := len(rlist) - 1; i >= 0; i-- {
 		r := rlist[i]
 
@@ -115,6 +121,7 @@ func restoreList(cn *pbm.PBM, size int64, full bool) (*restoreListOut, error) {
 			StartPointInTime: r.StartPITR,
 			PointInTime:      r.PITR,
 			Name:             r.Name,
+			Namespaces:       r.Namespaces,
 			Error:            r.Error,
 		}
 
@@ -145,10 +152,15 @@ func (bl backupListOut) String() string {
 	s := fmt.Sprintln("Backup snapshots:")
 
 	sort.Slice(bl.Snapshots, func(i, j int) bool {
-		return bl.Snapshots[i].StateTS < bl.Snapshots[j].StateTS
+		return bl.Snapshots[i].RestoreTS < bl.Snapshots[j].RestoreTS
 	})
 	for _, b := range bl.Snapshots {
-		s += fmt.Sprintf("  %s <%s> [complete: %s]\n", b.Name, b.Type, fmtTS(int64(b.StateTS)))
+		kind := string(b.Type)
+		if len(b.Namespaces) != 0 {
+			kind += ", selective"
+		}
+
+		s += fmt.Sprintf("  %s <%s> [restore_to_time: %s]\n", b.Name, kind, fmtTS(int64(b.RestoreTS)))
 	}
 	if bl.PITR.On {
 		s += fmt.Sprintln("\nPITR <on>:")
@@ -223,8 +235,9 @@ func getSnapshotList(cn *pbm.PBM, size int, rsMap map[string]string) (s []snapsh
 
 		s = append(s, snapshotStat{
 			Name:       b.Name,
+			Namespaces: b.Namespaces,
 			Status:     b.Status,
-			StateTS:    int64(b.LastWriteTS.T),
+			RestoreTS:  int64(b.LastWriteTS.T),
 			PBMVersion: b.PBMVersion,
 			Type:       b.Type,
 		})
