@@ -53,7 +53,9 @@ type PhysRestore struct {
 	// an ephemeral port to restart mongod on during the restore
 	tmpPort int
 	tmpConf *os.File
-	rsConf  *pbm.RSConfig // original replset config
+	rsConf  *pbm.RSConfig     // original replset config
+	shards  map[string]string // original shards list on config server
+	cfgConn string            // shardIdentity configsvrConnectionString
 	startTS int64
 	secOpts *pbm.MongodOptsSec
 
@@ -64,6 +66,10 @@ type PhysRestore struct {
 	bcp      *pbm.BackupMeta
 	files    []files
 
+	confOpts pbm.RestoreConf
+
+	mongod string // location of mongod used for internal restarts
+
 	// path to files on a storage the node will sync its
 	// state with the resto of the cluster
 	syncPathNode    string
@@ -105,6 +111,20 @@ func NewPhysical(cn *pbm.PBM, node *pbm.Node, inf *pbm.NodeInfo) (*PhysRestore,
 		return nil, errors.Wrap(err, "get replset config")
 	}
 
+	var shards map[string]string
+	var csvr string
+	if inf.IsConfigSrv() {
+		shards, err = node.GetShardsConfig()
+		if err != nil {
+			return nil, errors.Wrap(err, "get shards list")
+		}
+	} else if inf.IsSharded() {
+		csvr, err = node.ConfSvrConn()
+		if err != nil {
+			return nil, errors.Wrap(err, "get configsvrConnectionString")
+		}
+	}
+
 	if inf.SetName == "" {
 		return nil, errors.New("undefined replica set")
 	}
@@ -119,6 +139,8 @@ func NewPhysical(cn *pbm.PBM, node *pbm.Node, inf *pbm.NodeInfo) (*PhysRestore,
 		node:     node,
 		dbpath:   p,
 		rsConf:   rcf,
+		shards:   shards,
+		cfgConn:  csvr,
 		nodeInfo: inf,
 		tmpPort:  tmpPort,
 		secOpts:  opts.Security,
@@ -236,57 +258,56 @@ func waitMgoShutdown(dbpath string) error {
 // toState moves cluster to the given restore state.
 // All communication happens via files in the restore dir on storage.
 //
-//  Status "done" is a special case. If at least one node in the replset moved
-//  to the "done", the replset is "partlyDone". And a replset is "done" if all
-//  nodes moved to "done". For cluster success, all replsets must move either
-//  to "done" or "partlyDone". Cluster is "partlyDone" if at least one replset
-//  is "partlyDone".
+//		Status "done" is a special case. If at least one node in the replset moved
+//		to the "done", the replset is "partlyDone". And a replset is "done" if all
+//		nodes moved to "done". For cluster success, all replsets must move either
+//		to "done" or "partlyDone". Cluster is "partlyDone" if at least one replset
+//		is "partlyDone".
 //
-// - Each node writes a file with the given state.
-// - The replset leader (primary node) or every rs node, in case of status
-//   "done",  waits for files from all replica set nodes. And writes a status
-//   file for the replica set.
-// - The cluster leader (primary node - on config server in case of sharded) or
-//   every node, in case of status "done",  waits for status files from all
-//   replica sets. And sets the status file for the cluster.
-// - Each node in turn waits for the cluster status file and returns (move further)
-//   once it's observed.
+//	  - Each node writes a file with the given state.
+//	  - The replset leader (primary node) or every rs node, in case of status
+//	    "done",  waits for files from all replica set nodes. And writes a status
+//	    file for the replica set.
+//	  - The cluster leader (primary node - on config server in case of sharded) or
+//	    every node, in case of status "done",  waits for status files from all
+//	    replica sets. And sets the status file for the cluster.
+//	  - Each node in turn waits for the cluster status file and returns (move further)
+//	    once it's observed.
 //
 // State structure on storage:
 //
-//	.pbm.restore/<restore-name>
-// 		rs.<rs-name>/
-// 			node.<node-name>.hb			// hearbeats. last beat ts inside.
-// 			node.<node-name>.<status>	// node's PBM status. Inside is the ts of the transition. In case of error, file contains an error text.
-// 			rs.<status>					// replicaset's PBM status. Inside is the ts of the transition. In case of error, file contains an error text.
-//		cluster.hb						// hearbeats. last beat ts inside.
-// 		cluster.<status>				// cluster's PBM status. Inside is the ts of the transition. In case of error, file contains an error text.
+//		.pbm.restore/<restore-name>
+//			rs.<rs-name>/
+//				node.<node-name>.hb			// hearbeats. last beat ts inside.
+//				node.<node-name>.<status>	// node's PBM status. Inside is the ts of the transition. In case of error, file contains an error text.
+//				rs.<status>					// replicaset's PBM status. Inside is the ts of the transition. In case of error, file contains an error text.
+//			cluster.hb						// hearbeats. last beat ts inside.
+//			cluster.<status>				// cluster's PBM status. Inside is the ts of the transition. In case of error, file contains an error text.
 //
-//  For example:
-//
-//      2022-08-02T18:50:35.1889332Z
-//      ├── cluster.done
-//      ├── cluster.hb
-//      ├── cluster.running
-//      ├── cluster.starting
-//      ├── rs.rs1
-//      │   ├── node.rs101:27017.done
-//      │   ├── node.rs101:27017.hb
-//      │   ├── node.rs101:27017.running
-//      │   ├── node.rs101:27017.starting
-//      │   ├── node.rs102:27017.done
-//      │   ├── node.rs102:27017.hb
-//      │   ├── node.rs102:27017.running
-//      │   ├── node.rs102:27017.starting
-//      │   ├── node.rs103:27017.done
-//      │   ├── node.rs103:27017.hb
-//      │   ├── node.rs103:27017.running
-//      │   ├── node.rs103:27017.starting
-//      │   ├── rs.done
-//      │   ├── rs.hb
-//      │   ├── rs.running
-//      │   └── rs.starting
+//	 For example:
 //
+//	     2022-08-02T18:50:35.1889332Z
+//	     ├── cluster.done
+//	     ├── cluster.hb
+//	     ├── cluster.running
+//	     ├── cluster.starting
+//	     ├── rs.rs1
+//	     │   ├── node.rs101:27017.done
+//	     │   ├── node.rs101:27017.hb
+//	     │   ├── node.rs101:27017.running
+//	     │   ├── node.rs101:27017.starting
+//	     │   ├── node.rs102:27017.done
+//	     │   ├── node.rs102:27017.hb
+//	     │   ├── node.rs102:27017.running
+//	     │   ├── node.rs102:27017.starting
+//	     │   ├── node.rs103:27017.done
+//	     │   ├── node.rs103:27017.hb
+//	     │   ├── node.rs103:27017.running
+//	     │   ├── node.rs103:27017.starting
+//	     │   ├── rs.done
+//	     │   ├── rs.hb
+//	     │   ├── rs.running
+//	     │   └── rs.starting
 func (r *PhysRestore) toState(status pbm.Status) (rStatus pbm.Status, err error) {
 	defer func() {
 		if err != nil {
@@ -508,18 +529,18 @@ func (n nodeStatus) is(s nodeStatus) bool {
 // Unlike in logical restore, _every_ node of the replicaset is taking part in
 // a physical restore. In that way, we avoid logical resync between nodes after
 // the restore. Each node in the cluster does:
-// - Stores current replicset config and mongod port.
-// - Checks backup and stops all routine writes to the db.
-// - Stops mongod and wipes out datadir.
-// - Copies backup data to the datadir.
-// - Starts standalone mongod on ephemeral (tmp) port and reset some internal
-//   data also setting one-node replicaset and sets oplogTruncateAfterPoint
-//   to the backup's `last write`. `oplogTruncateAfterPoint` set the time up
-//   to which journals would be replayed.
-// - Starts standalone mongod to recover oplog from journals.
-// - Cleans up data and resets replicaset config to the working state.
-// - Shuts down mongod and agent (the leader also dumps metadata to the storage).
-func (r *PhysRestore) Snapshot(cmd *pbm.RestoreCmd, opid pbm.OPID, l *log.Event, stopAgentC chan<- struct{}) (err error) {
+//   - Stores current replicset config and mongod port.
+//   - Checks backup and stops all routine writes to the db.
+//   - Stops mongod and wipes out datadir.
+//   - Copies backup data to the datadir.
+//   - Starts standalone mongod on ephemeral (tmp) port and reset some internal
+//     data also setting one-node replicaset and sets oplogTruncateAfterPoint
+//     to the backup's `last write`. `oplogTruncateAfterPoint` set the time up
+//     to which journals would be replayed.
+//   - Starts standalone mongod to recover oplog from journals.
+//   - Cleans up data and resets replicaset config to the working state.
+//   - Shuts down mongod and agent (the leader also dumps metadata to the storage).
+func (r *PhysRestore) Snapshot(cmd *pbm.RestoreCmd, opid pbm.OPID, l *log.Event, stopAgentC chan<- struct{}, pauseHB func()) (err error) {
 	l.Debug("port: %d", r.tmpPort)
 
 	meta := &pbm.RestoreMeta{
@@ -582,14 +603,17 @@ func (r *PhysRestore) Snapshot(cmd *pbm.RestoreCmd, opid pbm.OPID, l *log.Event,
 		return errors.Wrapf(err, "moving to state %s", pbm.StatusRunning)
 	}
 
-	l.Info("send stopAgentC")
-
 	// On this stage, the agent has to be closed on any outcome as mongod
 	// is gonna be turned off. Besides, the agent won't be able to listen to
 	// the cmd stream anymore and will flood logs with errors on that.
+	l.Info("send to stopAgent chan")
 	if stopAgentC != nil {
 		stopAgentC <- struct{}{}
 	}
+	// anget will be stopped only after we exit this func
+	// so stop heartbeats not to spam logs while the restore is running
+	l.Debug("stop agents heartbeats")
+	pauseHB()
 
 	l.Info("stopping mongod and flushing old data")
 	err = r.flush()
@@ -867,6 +891,30 @@ func (r *PhysRestore) resetRS() error {
 		if err != nil {
 			return errors.Wrap(err, "drop config.lockpings")
 		}
+		for id, host := range r.shards {
+			_, err = c.Database("config").Collection("shards").UpdateOne(
+				ctx,
+				bson.D{{"_id", id}},
+				bson.D{
+					{"$set", bson.M{"host": host}},
+				},
+			)
+
+			if err != nil {
+				return errors.Wrapf(err, "update config.shards for %s %s", id, host)
+			}
+		}
+	} else {
+		_, err = c.Database("admin").Collection("system.version").UpdateOne(
+			ctx,
+			bson.D{{"_id", "shardIdentity"}},
+			bson.D{
+				{"$set", bson.M{"configsvrConnectionString": r.cfgConn}},
+			},
+		)
+		if err != nil {
+			return errors.Wrap(err, "update shardIdentity in admin.system.version")
+		}
 	}
 
 	err = c.Database("config").Collection("cache.collections").Drop(ctx)
@@ -1015,7 +1063,7 @@ func (r *PhysRestore) startMongo(opts ...string) error {
 	opts = append(opts, []string{"--logpath", path.Join(r.dbpath, internalMongodLog)}...)
 
 	errBuf := new(bytes.Buffer)
-	cmd := exec.Command("mongod", opts...)
+	cmd := exec.Command(r.mongod, opts...)
 
 	cmd.Stderr = errBuf
 	err := cmd.Start()
@@ -1041,6 +1089,14 @@ func (r *PhysRestore) init(name string, opid pbm.OPID, l *log.Event) (err error)
 		return errors.Wrap(err, "get storage")
 	}
 
+	r.mongod = "mongod" // run from $PATH by default
+	if r.confOpts.MongodLocation != "" {
+		r.mongod = r.confOpts.MongodLocation
+	}
+	if m, ok := r.confOpts.MongodLocationMap[r.nodeInfo.Me]; ok {
+		r.mongod = m
+	}
+
 	r.log = l
 
 	r.name = name
@@ -1292,6 +1348,12 @@ func (r *PhysRestore) prepareBackup(backupName string) (err error) {
 		return errors.Errorf("backup's Mongo version (%s) is not compatible with Mongo %s", r.bcp.MongoVersion, mgoV.VersionString)
 	}
 
+	mv, err := r.checkMongod(r.bcp.MongoVersion)
+	if err != nil {
+		return errors.Wrap(err, "check mongod binary")
+	}
+	r.log.Debug("mongod binary: %s, version: %s", r.mongod, mv)
+
 	err = r.setBcpFiles()
 	if err != nil {
 		return errors.Wrap(err, "get data for restore")
@@ -1340,6 +1402,34 @@ func (r *PhysRestore) prepareBackup(backupName string) (err error) {
 	return nil
 }
 
+// ensure mongod for internal restarts is available and matches
+// the backup's version
+func (r *PhysRestore) checkMongod(needVersion string) (version string, err error) {
+	cmd := exec.Command(r.mongod, "--version")
+
+	stderr := new(bytes.Buffer)
+	stdout := new(bytes.Buffer)
+
+	cmd.Stderr = stderr
+	cmd.Stdout = stdout
+
+	err = cmd.Run()
+	if err != nil {
+		return "", errors.Errorf("run: %v. stderr: %s", err, stderr)
+	}
+
+	_, v, ok := strings.Cut(strings.Split(stdout.String(), "\n")[0], "db version ")
+	if !ok {
+		return "", errors.Errorf("parse version from output %s", stdout.String())
+	}
+
+	if semver.Compare(majmin(needVersion), majmin(v)) != 0 {
+		return "", errors.Errorf("backup's Mongo version (%s) is not compatible with mongod %s", needVersion, v)
+	}
+
+	return v, nil
+}
+
 // MarkFailed sets the restore and rs state as failed with the given message
 func (r *PhysRestore) MarkFailed(meta *pbm.RestoreMeta, e error, markCluster bool) {
 	var nerr nodeErr
@@ -1366,16 +1456,16 @@ func (r *PhysRestore) MarkFailed(meta *pbm.RestoreMeta, e error, markCluster boo
 	// Here we are not aware of partlyDone etc so leave it to the `toState`.
 	if r.nodeInfo.IsPrimary && markCluster {
 		serr := r.stg.Save(r.syncPathRS+"."+string(pbm.StatusError),
-			errStatus(err), -1)
+			errStatus(e), -1)
 		if serr != nil {
-			r.log.Error("MarkFailed: write replset error state `%v`: %v", err, serr)
+			r.log.Error("MarkFailed: write replset error state `%v`: %v", e, serr)
 		}
 	}
 	if r.nodeInfo.IsClusterLeader() && markCluster {
 		serr := r.stg.Save(r.syncPathCluster+"."+string(pbm.StatusError),
-			errStatus(err), -1)
+			errStatus(e), -1)
 		if serr != nil {
-			r.log.Error("MarkFailed: write cluster error state `%v`: %v", err, serr)
+			r.log.Error("MarkFailed: write cluster error state `%v`: %v", e, serr)
 		}
 	}
 }
